Plugin: JS9Cube

### JS9 FITS Data Cubes

The Data Cube plugin allows you to display slices from a FITS 3D data cube. You can choose the particular slice to display using the slider, text box, or navigation buttons. You also can blink the slices in order using the blink and stop buttons. The default blink interval is one second, but this can be changed with the rate menu.

By default, the slice axis is the third axis of the cube. Use the menu at the right to specify a different slice axis.

You also can load each slice separately into JS9 with the Load All button. Each slice will be identified by the original filename with a <n> suffix, where n is the slice number. Loading all slices separately allows you to blend the cube images or set up RGB mode (on any three of them).

The underlying public access routine, JS9.DisplaySlice(), also works on FITS 4D data cubes. This plugin will be extended to support 4D cubes if there is a need within the astronomical community.